@@ -10,6 +10,15 @@ def display(message: str, button_text: str = 'Next'):
     '''
     return Page().display(message).run(button_text)
 
+def display_markdown(text: str, button_text: str = 'Next'):
+    '''Display a formatted text to the user
+
+    Args:
+        text (str): The formatted text to display to the user
+        button_text (str): The text to display on the button that will continue the form
+    '''
+    return Page().display_markdown(text).run(button_text)
+
 
 def display_image(image_str: str, subtitle: str = "", button_text: str = 'Next'):
     '''Display an image to the user
